Custom Color Scale for ggplot2: American Marketing Association Style
ama_scale_color.RdThis function provides a custom color scale for ggplot2 plots based on the guidelines set by the American Marketing Association.
Usage
ama_scale_color(
use_color = FALSE,
palette_name = "OkabeIto",
grayscale_limits = c(0.2, 0.8)
)