Nice Tabulation Function
nice_tab.RdCreate a custom function that takes a data frame and a number of decimal places as input, rounds all numeric columns in the data frame to the specified number of decimal places, and returns the modified data frame.