Custom Fill Scale for ggplot2: American Marketing Association Style
ama_scale_fill.RdThis function provides a custom fill scale for ggplot2 plots based on the guidelines set by the American Marketing Association.
Usage
ama_scale_fill(
use_color = FALSE,
palette_name = "OkabeIto",
grayscale_limits = c(0.2, 0.8)
)