Skip to contents

Identifies minimal sufficient adjustment sets for estimating the causal effect of exposure on outcome in a given DAG.

Usage

dag_adjustment_sets(
  dag_string,
  exposure,
  outcome,
  type = c("minimal", "canonical", "all")
)

Arguments

dag_string

Character or dagitty object. The causal DAG.

exposure

Character. Treatment node name.

outcome

Character. Outcome node name.

type

Character. "minimal" (default), "canonical", or "all".

Value

A list of adjustment sets (each set is a character vector).

Examples

dag_adjustment_sets(
  "dag{ X -> Y; Z -> X; Z -> Y; U -> Z; U -> Y }",
  exposure = "X", outcome = "Y"
)
#> $`1`
#> [1] "Z"
#>